License:
--------
By downloading and using this software you agree to the license here:
{}

Download and Installation:
--------------------------
The package is available on Anaconda

If you are using Anaconda, make sure you are pulling from channel conda-forge
Install the package (If you are using a conda environment make sure to
activate it first):

.. code-block:: bash

    >>> conda install {} -c conda-forge

If you do not use conda (and we recommend you do) you may download and build
the sources from the links below.  Unpack the sources, then in the base
directory type

.. code-block:: bash

    >>> python setup.py install
